gtrace package
==============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   gtrace.draw
   gtrace.optics

Submodules
----------

gtrace.beam module
------------------

.. automodule:: gtrace.beam
   :members:
   :undoc-members:
   :show-inheritance:

gtrace.hello module
-------------------

.. automodule:: gtrace.hello
   :members:
   :undoc-members:
   :show-inheritance:

gtrace.nonsequential module
---------------------------

.. automodule:: gtrace.nonsequential
   :members:
   :undoc-members:
   :show-inheritance:

gtrace.optcomp module
---------------------

.. automodule:: gtrace.optcomp
   :members:
   :undoc-members:
   :show-inheritance:

gtrace.unit module
------------------

.. automodule:: gtrace.unit
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: gtrace
   :members:
   :undoc-members:
   :show-inheritance:
